require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xspdatabaseaag',
  dscmeta_resource_friendly_name: 'xSPDatabaseAAG',
  dscmeta_resource_name: 'MSFT_xSPDatabaseAAG',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xSharePoint',
  dscmeta_module_version: '0.12.0.0',
  docs: 'The DSC xSPDatabaseAAG resource type.
         Automatically generated from version 0.12.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_installaccount: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'POWERSHELL 4 ONLY: The account to run this resource as, use PsDscRunAsAccount if using PowerShell 5',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Enum['Present', 'Absent']",
      desc: 'Present if the database should be in this AlwaysOn group, or Absent if it should not be in the group',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_agname: {
      type: 'String',
      desc: 'Name of the AlwaysOn group on the SQL server - this must already exist',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fileshare: {
      type: 'Optional[String]',
      desc: 'The fileshare to use for the SQL backup when adding to the group',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasename: {
      type: 'String',
      desc: 'The name of the database to put in the AlwaysOn group',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
