require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xspdistributedcacheservice',
  dscmeta_resource_friendly_name: 'xSPDistributedCacheService',
  dscmeta_resource_name: 'MSFT_xSPDistributedCacheService',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xSharePoint',
  dscmeta_module_version: '0.12.0.0',
  docs: 'The DSC xSPDistributedCacheService resource type.
         Automatically generated from version 0.12.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_name: {
      type: 'String',
      desc: 'A name to assign to this resource - not really used. For example - AppFabricCachingService',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_installaccount: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'POWERSHELL 4 ONLY: The account to run this resource as, use PsDscRunAsAccount if using PowerShell 5',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Enum['Present', 'Absent']",
      desc: "Present to ensure the current server should be running distributed cache, absent to ensure that it isn't running",

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_createfirewallrules: {
      type: 'Boolean',
      desc: 'Should the Windows Firewall rules for distributed cache be created?',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_cachesizeinmb: {
      type: 'Integer[0, 4294967295]',
      desc: 'How many MB should be used for the cache. The maximum supported is 16384',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_serviceaccount: {
      type: 'String',
      desc: 'The name of the service account to run the service as. This should already be registered as a managed account in SharePoint',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_serverprovisionorder: {
      type: 'Optional[Array[String]]',
      desc: 'A list of servers which specifies the order they should provision the cache in to ensure that two servers do not do it at the same time',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
