require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xspinstallprereqs',
  dscmeta_resource_friendly_name: 'xSPInstallPrereqs',
  dscmeta_resource_name: 'MSFT_xSPInstallPrereqs',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xSharePoint',
  dscmeta_module_version: '0.12.0.0',
  docs: 'The DSC xSPInstallPrereqs resource type.
         Automatically generated from version 0.12.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_appfabric: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_msipcclient: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dotnet452: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_idfx: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wcfdataservices56: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_kb3092423: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_installerpath: {
      type: 'String',
      desc: 'The full path to prerequisiteinstaller.exe',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Enum['Present', 'Absent']",
      desc: 'Present to install the prerequisites. Absent is currently not supported',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_odbc: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlncli: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_kb2898850: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_netfx: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_idfx11: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_powershell: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_msvcrt11: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_onlinemode: {
      type: 'Boolean',
      desc: 'Should the installer download prerequisites from the internet or not',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_wcfdataservices: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sync: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_msvcrt14: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_kb2671763: {
      type: 'Optional[String]',
      desc: 'The path to the installer for this prerequisite',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
