require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xspshelladmins',
  dscmeta_resource_friendly_name: 'xSPShellAdmins',
  dscmeta_resource_name: 'MSFT_xSPShellAdmins',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xSharePoint',
  dscmeta_module_version: '0.12.0.0',
  docs: 'The DSC xSPShellAdmins resource type.
         Automatically generated from version 0.12.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_allcontentdatabases: {
      type: 'Optional[Boolean]',
      desc: 'Specify if all content databases must get the same config as the general config',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name for the config, used for administration purposes',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_installaccount: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'POWERSHELL 4 ONLY: The account to run this resource as, use PsDscRunAsAccount if using PowerShell 5',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_memberstoinclude: {
      type: 'Optional[Array[String]]',
      desc: 'List of all accounts that must be in the Shell Admins group',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_contentdatabases: {
      type: 'Optional[Array[Struct[{
              memberstoexclude => Optional[Array[String]],
              name => Optional[String],
              memberstoinclude => Optional[Array[String]],
              members => Optional[Array[String]],
            }]]]',
      desc: 'Shell Admin configuration of Content Databases',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_xSPContentDatabasePermissions[]',
      mof_is_embedded: true,
    },
    dsc_members: {
      type: 'Optional[Array[String]]',
      desc: 'Exact list of accounts that will have to get Shell Admin permissions',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_memberstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'List of all accounts that are not allowed to have Shell Admin permissions',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
