require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xspwebapplication',
  dscmeta_resource_friendly_name: 'xSPWebApplication',
  dscmeta_resource_name: 'MSFT_xSPWebApplication',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xSharePoint',
  dscmeta_module_version: '0.12.0.0',
  docs: 'The DSC xSPWebApplication resource type.
         Automatically generated from version 0.12.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_url: {
      type: 'String',
      desc: 'The URL of the web application',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_hostheader: {
      type: 'Optional[String]',
      desc: 'The host header to use for the web app',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowanonymous: {
      type: 'Optional[Boolean]',
      desc: 'Should anonymous access be enabled for this web app',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the web application',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authenticationmethod: {
      type: "Optional[Enum['NTLM', 'Kerberos']]",
      desc: 'What authentication mode should be used for the web app',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databaseserver: {
      type: 'Optional[String]',
      desc: 'The name of the database server to host the default content DB',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationpoolaccount: {
      type: 'String',
      desc: 'The name of the managed account to run the app pool with',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasename: {
      type: 'Optional[String]',
      desc: 'The name of the first content database to be created with this web app',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationpool: {
      type: 'String',
      desc: 'The name of the application pool to run this site in',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usessl: {
      type: 'Optional[Boolean]',
      desc: 'Should this web app use SSL',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_installaccount: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'POWERSHELL 4 ONLY: The account to run this resource as, use PsDscRunAsAccount if using PowerShell 5',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_path: {
      type: 'Optional[String]',
      desc: 'The path on the local servers to host the IIS web site from',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_port: {
      type: 'Optional[String]',
      desc: 'The port to run the site on',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
